@@ -19,18 +19,18 @@
 
 /**
  * SECTION:element-rtpac3depay
+ * @title: rtpac3depay
  * @see_also: rtpac3pay
  *
  * Extract AC3 audio from RTP packets according to RFC 4184.
  * For detailed information see: http://www.rfc-editor.org/rfc/rfc4184.txt
  *
- * <refsect2>
- * <title>Example pipeline</title>
+ * ## Example pipeline
  * |[
  * gst-launch-1.0 udpsrc caps='application/x-rtp, media=(string)audio, clock-rate=(int)44100, encoding-name=(string)AC3, payload=(int)96' ! rtpac3depay ! a52dec ! pulsesink
  * ]| This example pipeline will depayload and decode an RTP AC3 stream. Refer to
  * the rtpac3pay example to create the RTP stream.
- * </refsect2>
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,6 +41,7 @@
 #include <gst/audio/audio.h>
 
 #include <string.h>
+#include "gstrtpelements.h"
 #include "gstrtpac3depay.h"
 #include "gstrtputils.h"
 
@@ -51,7 +52,7 @@ static GstStaticPadTemplate gst_rtp_ac3_depay_src_template =
 GST_STATIC_PAD_TEMPLATE ("src",
     GST_PAD_SRC,
     GST_PAD_ALWAYS,
-    GST_STATIC_CAPS ("audio/ac3")
+    GST_STATIC_CAPS ("audio/x-ac3")
     );
 
 static GstStaticPadTemplate gst_rtp_ac3_depay_sink_template =
@@ -65,6 +66,8 @@ GST_STATIC_PAD_TEMPLATE ("sink",
     );
 
 G_DEFINE_TYPE (GstRtpAC3Depay, gst_rtp_ac3_depay, GST_TYPE_RTP_BASE_DEPAYLOAD);
+GST_ELEMENT_REGISTER_DEFINE_WITH_CODE (rtpac3depay, "rtpac3depay",
+    GST_RANK_SECONDARY, GST_TYPE_RTP_AC3_DEPAY, rtp_element_init (plugin));
 
 static gboolean gst_rtp_ac3_depay_setcaps (GstRTPBaseDepayload * depayload,
     GstCaps * caps);
@@ -117,7 +120,7 @@ gst_rtp_ac3_depay_setcaps (GstRTPBaseDepayload * depayload, GstCaps * caps)
     clock_rate = 90000;         /* default */
   depayload->clock_rate = clock_rate;
 
-  srccaps = gst_caps_new_empty_simple ("audio/ac3");
+  srccaps = gst_caps_new_empty_simple ("audio/x-ac3");
   res = gst_pad_set_caps (depayload->srcpad, srccaps);
   gst_caps_unref (srccaps);
 
@@ -171,10 +174,3 @@ empty_packet:
     return NULL;
   }
 }
-
-gboolean
-gst_rtp_ac3_depay_plugin_init (GstPlugin * plugin)
-{
-  return gst_element_register (plugin, "rtpac3depay",
-      GST_RANK_SECONDARY, GST_TYPE_RTP_AC3_DEPAY);
-}
